@@ -19,8 +19,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _ha_mroonga_hpp
-#define _ha_mroonga_hpp
+#ifndef HA_MROONGA_HPP_
+#define HA_MROONGA_HPP_
 
 #ifdef USE_PRAGMA_INTERFACE
 #pragma interface
@@ -40,7 +40,7 @@ extern "C" {
 #  define MRN_HANDLER_CLONE_NEED_NAME 1
 #endif
 
-#if (MYSQL_VERSION_ID >= 50514 && (MYSQL_VERSION_ID < 50600 || defined(MRN_MARIADB_P)))
+#if (MYSQL_VERSION_ID >= 50514 && MYSQL_VERSION_ID < 50600)
 #  define MRN_HANDLER_HAVE_FINAL_ADD_INDEX 1
 #endif
 
@@ -63,7 +63,7 @@ extern "C" {
 #  define MRN_HANDLER_HAVE_MULTI_RANGE_READ 1
 #endif
 
-#if (MYSQL_VERSION_ID >= 50607) && !defined(MRN_MARIADB_P)
+#if (MYSQL_VERSION_ID >= 50607)
 #  define MRN_HANDLER_HAVE_CHECK_IF_SUPPORTED_INPLACE_ALTER 1
 #  define MRN_HANDLER_HAVE_HA_PREPARE_INPLACE_ALTER_TABLE 1
 #  define MRN_HANDLER_HAVE_HA_INPLACE_ALTER_TABLE 1
@@ -147,10 +147,6 @@ extern "C" {
 #  define MRN_JOIN_TAB_HAVE_CONDITION
 #endif
 
-#if MYSQL_VERSION_ID >= 50607 && !defined(MRN_MARIADB_P)
-#  define MRN_ITEM_HAVE_ITEM_NAME
-#endif
-
 #if MYSQL_VERSION_ID < 50600
 #  define MRN_RBR_UPDATE_NEED_ALL_COLUMNS
 #endif
@@ -164,26 +160,10 @@ extern "C" {
 #  define MRN_HAVE_HA_REBIND_PSI
 #endif
 
-#if MYSQL_VERSION_ID >= 50607
-#  define MRN_GET_ERROR_MESSAGE current_thd->get_stmt_da()->message()
-#else
-#  if MYSQL_VERSION_ID >= 50500
-#    define MRN_GET_ERROR_MESSAGE current_thd->stmt_da->message()
-#  else
-#    define MRN_GET_ERROR_MESSAGE current_thd->main_da.message()
-#  endif
-#endif
-
 #if MYSQL_VERSION_ID >= 50612 && !defined(MRN_MARIADB_P)
 #  define MRN_HAVE_POINT_XY
 #endif
 
-#if defined(_WIN32) || defined(_WIN64)
-#  define MRN_API __declspec(dllexport)
-#else
-#  define MRN_API
-#endif
-
 #if (defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100000)
 #  define MRN_HANDLER_START_BULK_INSERT_HAS_FLAGS
 #endif
@@ -572,9 +552,6 @@ private:
   bool is_temporary_table_name(const char *name) const;
   void check_count_skip(key_part_map start_key_part_map,
                         key_part_map end_key_part_map, bool fulltext);
-  bool is_groonga_layer_condition(const Item *item,
-                                  const Item_func **match_against=NULL);
-  bool is_fulltext_search_item(const Item *item);
   bool is_grn_zero_column_value(grn_obj *column, grn_obj *value);
   void check_fast_order_limit(grn_table_sort_key **sort_keys, int *n_sort_keys,
                               longlong *limit);
@@ -1167,4 +1144,4 @@ private:
 }
 #endif
 
-#endif /* _ha_mroonga_hpp */
+#endif /* HA_MROONGA_HPP_ */
