@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
-  Copyright(C) 2011 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2011-2013 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -17,8 +17,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _mrn_mysql_compat_h
-#define _mrn_mysql_compat_h
+#ifndef MRN_MYSQL_COMPAT_H_
+#define MRN_MYSQL_COMPAT_H_
 
 #include "mrn_mysql.h"
 
@@ -60,7 +60,7 @@
   typedef char *range_id_t;
 #endif
 
-#if MYSQL_VERSION_ID >= 50609 && !defined(MRN_MARIADB_P)
+#if MYSQL_VERSION_ID >= 50609
 #  define MRN_KEY_HAS_USER_DEFINED_KEYPARTS
 #endif
 
@@ -83,4 +83,35 @@
 #  define FN_LIBCHAR2 FN_LIBCHAR
 #endif
 
-#endif /* _mrn_mysql_compat_h */
+#if MYSQL_VERSION_ID >= 50607
+#  define MRN_GET_ERROR_MESSAGE current_thd->get_stmt_da()->message()
+#else
+#  if MYSQL_VERSION_ID >= 50500
+#    define MRN_GET_ERROR_MESSAGE current_thd->stmt_da->message()
+#  else
+#    define MRN_GET_ERROR_MESSAGE current_thd->main_da.message()
+#  endif
+#endif
+
+#if MYSQL_VERSION_ID >= 50607 && !defined(MRN_MARIADB_P)
+#  define MRN_ITEM_HAVE_ITEM_NAME
+#endif
+
+#if MYSQL_VERSION_ID >= 50500 && \
+  !(defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100004)
+#  define MRN_HAVE_TABLE_DEF_CACHE
+#endif
+
+#if defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100004
+#  define MRN_HAVE_TDC_ACQUIRE_SHARE
+#endif
+
+#if MYSQL_VERSION_ID >= 50613
+#  define MRN_HAVE_ALTER_INFO
+#endif
+
+#if MYSQL_VERSION_ID >= 50603
+#  define MRN_HAVE_GET_TABLE_DEF_KEY
+#endif
+
+#endif /* MRN_MYSQL_COMPAT_H_ */
